@@ -43,16 +43,16 @@ HTMLIFrameClass html_iframe_class;
 static HTMLEmbeddedClass *parent_class = NULL;
 
 static void
-iframe_set_base (GtkHTML *html, const char *url, gpointer data)
+iframe_set_base (GtkHTML *html, const gchar *url, gpointer data)
 {
-	char *new_url = gtk_html_get_url_base_relative (html, url);
+	gchar *new_url = gtk_html_get_url_base_relative (html, url);
 
 	gtk_html_set_base (html, new_url);
 	g_free (new_url);
 }
 
 static void
-iframe_url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle, gpointer data)
+iframe_url_requested (GtkHTML *html, const gchar *url, GtkHTMLStream *handle, gpointer data)
 {
 	HTMLIFrame *iframe = HTML_IFRAME (data);
 	GtkHTML *parent = GTK_HTML (HTML_EMBEDDED(iframe)->parent);
@@ -96,7 +96,7 @@ iframe_set_gdk_painter (HTMLIFrame *iframe, HTMLPainter *painter)
 
 HTMLObject *
 html_iframe_new (GtkWidget *parent,
-		 char *src,
+		 gchar *src,
 		 gint width,
 		 gint height,
 		 gboolean border)
@@ -216,7 +216,7 @@ static gint
 check_page_split (HTMLObject *self, HTMLPainter *p, gint y)
 {
 	HTMLEngine *e = GTK_HTML (HTML_IFRAME (self)->html)->engine;
-	int y1, y2, pixel_size = html_painter_get_pixel_size (p);
+	gint y1, y2, pixel_size = html_painter_get_pixel_size (p);
 
 	y1 = self->y - self->ascent + pixel_size*html_engine_get_top_border (e);
 	y2 = self->y + self->descent + pixel_size*html_engine_get_bottom_border (e);
@@ -274,7 +274,7 @@ op_copy (HTMLObject *self, HTMLObject *parent, HTMLEngine *e, GList *from, GList
 }
 
 static HTMLAnchor *
-find_anchor (HTMLObject *self, const char *name, gint *x, gint *y)
+find_anchor (HTMLObject *self, const gchar *name, gint *x, gint *y)
 {
 	HTMLIFrame *iframe;
 	HTMLAnchor *anchor;
@@ -493,7 +493,7 @@ save (HTMLObject *s,
 		}
 		html_engine_save_buffer_free (buffer, TRUE);
 	} else {
-		if (!html_engine_save_output_string (state, "<IFRAME SRC=\"%s\"", iframe->url))
+		if (!html_engine_save_delims_and_vals (state, "<IFRAME SRC=\"", iframe->url, "\"", NULL))
 			 return FALSE;
 
 		 if (iframe->width >= 0)
@@ -569,7 +569,7 @@ void
 html_iframe_init (HTMLIFrame *iframe,
 		  HTMLIFrameClass *klass,
 		  GtkWidget *parent,
-		  char *src,
+		  gchar *src,
 		  gint width,
 		  gint height,
 		  gboolean border)
@@ -615,7 +615,7 @@ html_iframe_init (HTMLIFrame *iframe,
 
 	gtk_html_set_default_engine (new_html,
 					   gtk_html_get_default_engine(parent_html));
-					   
+
 	iframe->html = new_widget;
 	iframe->url = g_strdup (src);
 	iframe->width = width;
@@ -649,20 +649,15 @@ html_iframe_init (HTMLIFrame *iframe,
 	 * on_url and link_clicked are emitted from the toplevel widget not
 	 * proxied like url_requested is.
 	 */
-	gtk_signal_connect (GTK_OBJECT (new_html), "on_url",
-			    G_CALLBACK (iframe_on_url),
-			    (gpointer)iframe);
-	gtk_signal_connect (GTK_OBJECT (new_html), "link_clicked",
-			    G_CALLBACK (iframe_link_clicked),
-			    (gpointer)iframe);
+	g_signal_connect (new_html, "on_url", G_CALLBACK (iframe_on_url), iframe);
+	g_signal_connect (new_html, "link_clicked", G_CALLBACK (iframe_link_clicked), iframe);
 #endif
 	g_signal_connect (new_html, "size_changed", G_CALLBACK (iframe_size_changed), iframe);
 	g_signal_connect (new_html, "set_base", G_CALLBACK (iframe_set_base), iframe);
 	g_signal_connect (new_html, "object_requested", G_CALLBACK (iframe_object_requested), iframe);
 
 	/*
-	  gtk_signal_connect (GTK_OBJECT (html), "button_press_event",
-	  G_CALLBACK (iframe_button_press_event), iframe);
+	  g_signal_connect (html, "button_press_event", G_CALLBACK (iframe_button_press_event), iframe);
 	*/
 
 	gtk_widget_set_size_request (scrolled_window, width, height);
@@ -680,14 +675,10 @@ html_iframe_init (HTMLIFrame *iframe,
 				     parent_html->engine->settings->color_set);
 	html_painter_set_focus (new_html->engine->painter, parent_html->engine->have_focus);
 	/*
-	gtk_signal_connect (GTK_OBJECT (html), "title_changed",
-			    G_CALLBACK (title_changed_cb), (gpointer)app);
-	gtk_signal_connect (GTK_OBJECT (html), "button_press_event",
-			    G_CALLBACK (on_button_press_event), popup_menu);
-	gtk_signal_connect (GTK_OBJECT (html), "redirect",
-			    G_CALLBACK (on_redirect), NULL);
-	gtk_signal_connect (GTK_OBJECT (html), "object_requested",
-			    G_CALLBACK (object_requested_cmd), NULL);
+	g_signal_connect (html, "title_changed", G_CALLBACK (title_changed_cb), (gpointer)app);
+	g_signal_connect (html, "button_press_event", G_CALLBACK (on_button_press_event), popup_menu);
+	g_signal_connect (html, "redirect", G_CALLBACK (on_redirect), NULL);
+	g_signal_connect (html, "object_requested", G_CALLBACK (object_requested_cmd), NULL);
 	*/
 }
 
@@ -700,7 +691,7 @@ html_iframe_type_init (void)
 void
 html_iframe_class_init (HTMLIFrameClass *klass,
 			HTMLType type,
-		        guint size)
+			guint size)
 {
 	HTMLEmbeddedClass *embedded_class;
 	HTMLObjectClass  *object_class;
